intelmq.bots.outputs.xmpp package — intelmq 2.3.3.alpha1 documentation

# intelmq.bots.outputs.xmpp package

## Submodules

## intelmq.bots.outputs.xmpp.output module

XMPP Output Bot Connects to a XMPP Server and sends data to a user.

TLS is used by default.

Tested with Python >= 3.4 Tested with sleekxmpp >= 1.0.0-beta5

Copyright (C) 2016 by Bundesamt für Sicherheit in der Informationstechnik Software engineering by Intevation GmbH

Parameters: ca_certs: string to a CA-bundle file or false/empty string for no checks hierarchical_output: boolean (false by default) xmpp_user: string xmpp_server: string xmpp_password: boolean xmpp_to_user: string xmpp_to_server: string xmpp_room: string xmpp_room_nick: string xmpp_room_password: string use_muc: boolean

`intelmq.bots.outputs.xmpp.output.` `BOT`

  alias of `intelmq.bots.outputs.xmpp.output.XMPPOutputBot`

class `intelmq.bots.outputs.xmpp.output.` `XMPPOutputBot`(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.Bot`

  `init`()
  `process`()
  `shutdown`()
  `xmpp` = None

## Module contents